@@ -1,12 +1,35 @@
 '''
 mdbase.data
 -----------
-Additional manipulations with data in the input database.
+Additional manipulations with data in package MDBASE.
+
+* MDBASE joins multiple XLSX databases into one pandas.DataFrame object.
+    - functions in this module modify the (joined) database = df
+* MDBASE has been developed for UHMWPE project:
+    - https://mirekslouf.webnode.cz/uhmwpe
+    - data manipulations in this module are focused on UHMWPE project data
 '''
 
 import numpy as np
 
 def add_normalized_OI(df):
+    '''
+    Add normalized OI values to database.
+    
+    * database = pandas.Dataframe object
+    * normalized OI values = OI values divided by LenghtInVivo
+
+    Parameters
+    ----------
+    df :  pandas.DataFrame object
+        Original database containing all data (from joined XLSX databases).
+
+    Returns
+    -------
+    df : pandas.DataFrame object
+        Augmented database with newly inserted columns.
+
+    '''
     LengthInVivo = replace_non_numeric_values(df.LengthInVivo)
     OI_ave_W = replace_non_numeric_values(df.OI_ave_W)
     OI_max_W = replace_non_numeric_values(df.OI_max_W)
